<?php

declare(strict_types=1);

namespace Dedi\SyliusMegamenuPlugin\Entity;

use Dedi\SyliusMegamenuPlugin\Enum\EntryTypes;
use Doctrine\Common\Collections\Collection;
use Sylius\Component\Resource\Model\TranslationInterface;

class DirectLinkCollectionEntry extends Entry implements DirectLinkCollectionEntryInterface
{
    public function getType(): string
    {
        return EntryTypes::DIRECT_LINK_COLLECTION;
    }

    protected function createTranslation(): TranslationInterface
    {
        return new DirectLinkCollectionEntryTranslation();
    }

    public function getDirectLinks(): Collection
    {
        /** @var DirectLinkCollectionEntryTranslationInterface $translation */
        $translation = $this->getTranslation();

        return $translation->getDirectLinkCollection();
    }

    public function addDirectLink(DirectLinkEntryInterface $directLinkEntry): DirectLinkCollectionEntryInterface
    {
        /** @var DirectLinkCollectionEntryTranslationInterface $translation */
        $translation = $this->getTranslation();
        $translation->addDirectLink($directLinkEntry);

        return $this;
    }

    public function removeDirectLink(DirectLinkEntryInterface $directLinkEntry): DirectLinkCollectionEntryInterface
    {
        /** @var DirectLinkCollectionEntryTranslationInterface $translation */
        $translation = $this->getTranslation();
        $translation->removeDirectLink($directLinkEntry);

        return $this;
    }

    public function hasDirectLink(DirectLinkEntryInterface $directLinkEntry): bool
    {
        /** @var DirectLinkCollectionEntryTranslationInterface $translation */
        $translation = $this->getTranslation();

        return $translation->hasDirectLink($directLinkEntry);
    }

    public function getLabel(): ?string
    {
        /** @var DirectLinkEntryTranslationInterface $translation */
        $translation = $this->getTranslation();

        return $translation->getLabel();
    }

    public function setLabel(?string $label): DirectLinkCollectionEntryInterface
    {
        /** @var DirectLinkEntryTranslationInterface $translation */
        $translation = $this->getTranslation();
        $translation->setLabel($label);

        return $this;
    }
}
